Evaluation Utilities
====================

Utility functions supporting the evaluation modules.

Data Conversion
---------------

.. automodule:: shepherd_score.evaluations.utils.convert_data
   :members:
   :undoc-members:
   :show-inheritance:

Protein & Ligand Preparation
-----------------------------

.. automodule:: shepherd_score.evaluations.utils.interactions
   :members:
   :undoc-members:
   :show-inheritance:
